# Introduction

Growing numbers of National Research and Education Networks (NREN) are
interested in automating and orchestrating their network portfolio. However,
individual NRENs may be at different levels of engagement, ranging from
interested but with no concrete plans as yet, to fully automated and
orchestrated. Of the many commercial and open-source tools that can be used,
the NREN community’s interest appears to be focused on Ansible and NSO for the
automation part and on Workflow Orchestrator (WFO) for the orchestration part.
Although the WFO is agnostic to the domain it is used in, this section
describes, as an example that will be recognised by NREN, a set of network
service products that are common to this community and can be used in
combination with the Workflow Orchestrator.
